// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef OKULAR_VERSION_H
#define OKULAR_VERSION_H

#define OKULAR_VERSION_STRING "26.04.0"
#define OKULAR_VERSION_MAJOR 26
#define OKULAR_VERSION_MINOR 4
#define OKULAR_VERSION_PATCH 0
#define OKULAR_VERSION ((26<<16)|(4<<8)|(0))

#endif
